==> dash-tools-1.10.5.tar.gz: dash-tools-1.10.5/src/dashtools/dashboard/alerts.py <==
import dash_mantine_components as dmc
from dash_iconify import DashIconify

# NOTIFICATION_DURATION_SECONDS = 8


def render(key: str):
    if key == 'FileNotFoundError':
        return dmc.Notification(
            message="The file path you provided does not exist. Please check your filepath and try again.",
            title="Warning",
            color='red',
            icon=[DashIconify(icon="ep:warning")],
            action='show',
            id='error-file-not-found'
        )
    elif key == 'PermissionError':
        return dmc.Notification(
            message="You do not have sufficient permission to access that file!",
            title="Warning",
            color='red',
            icon=[DashIconify(icon="ep:warning")],
            action='show',
            id='error-permissions'
        )
    elif key == 'FileRequiredError':
        return dmc.Notification(
            message="You must have an Open File in File Explorer to do this action!",
            title="Warning",
            color='red',
            icon=[DashIconify(icon="ep:warning")],
            action='show',
            id='error-permissions'
        )
    elif key == 'NameRequiredError':
        return dmc.Notification(
            message="A Render App Name is required to do this action!",
            title="Warning",
            color='red',
            icon=[DashIconify(icon="ep:warning")],
            action='show',
            id='error-permissions'
        )
    elif key == 'GitNotInstalledError':
        return dmc.Notification(
            message="Git must be installed on your system to deploy to Render.com!",
            title="Warning",
            color='red',
            icon=[DashIconify(icon="ep:warning")],
            action='show',
            id='error-permissions'
        )
    elif key == 'NotGitRepoError':
        return dmc.Notification(
            message="You must publish your project to Git before continuing!",
            title="Warning",
            color='red',
            icon=[DashIconify(icon="ep:warning")],
            action='show',
            id='error-permissions'
        )

==> dash-tools-1.11.0.tar.gz: dash-tools-1.11.0/src/dashtools/dashboard/alerts.py <==
import dash_mantine_components as dmc
from dash_iconify import DashIconify

# NOTIFICATION_DURATION_SECONDS = 8


def render(key: str, props: any=None) -> dmc.Notification:
    if key == 'FileNotFoundError':
        return dmc.Notification(
            message="The file path you provided does not exist. Please check your filepath and try again.",
            title="Warning",
            color='red',
            icon=[DashIconify(icon="ep:warning")],
            action='show',
            id='error-file-not-found'
        )
    elif key == 'PermissionError':
        return dmc.Notification(
            message="You do not have sufficient permission to access that file!",
            title="Warning",
            color='red',
            icon=[DashIconify(icon="ep:warning")],
            action='show',
            id='error-permissions'
        )
    elif key == 'FileRequiredError':
        return dmc.Notification(
            message="You must have an Open File in File Explorer to do this action!",
            title="Warning",
            color='red',
            icon=[DashIconify(icon="ep:warning")],
            action='show',
            id='error-permissions'
        )
    elif key == 'NameRequiredError':
        return dmc.Notification(
            message="A Render App Name is required to do this action!",
            title="Warning",
            color='red',
            icon=[DashIconify(icon="ep:warning")],
            action='show',
            id='error-permissions'
        )
    elif key == 'GitNotInstalledError':
        return dmc.Notification(
            message="Git must be installed on your system to deploy to Render.com!",
            title="Warning",
            color='red',
            icon=[DashIconify(icon="ep:warning")],
            action='show',
            id='error-permissions'
        )
    elif key == 'NotGitRepoError':
        return dmc.Notification(
            message="You must publish your project to Git before continuing!",
            title="Warning",
            color='red',
            icon=[DashIconify(icon="ep:warning")],
            action='show',
            id='error-permissions'
        )
    elif key == 'ModuleNotFound':
        return dmc.Notification(
            message=f"You must install module '{props.needs_module}' to preview this app!",
            title="Warning",
            color='red',
            icon=[DashIconify(icon="ep:warning")],
            action='show',
            id='error-permissions',
        )
    elif key == 'FileAlreadyExists':
        return dmc.Notification(
            message=f"File {props.filepath} already exists at this location! Please change app name or create location and try again.",
            title="Warning",
            color='red',
            icon=[DashIconify(icon="ep:warning")],
            action='show',
            id='error-permissions',
        )
    elif key == 'AppCreateSuccess':
        return dmc.Notification(
            message=f"App created successfully!",
            title="Success",
            color='green',
            icon=[DashIconify(icon="ep:success-filled")],
            action='show',
            id='error-permissions',
        )
